@@ -2,7 +2,7 @@ package RedisDB;
 
 use strict;
 use warnings;
-our $VERSION = "2.37";
+our $VERSION = "2.38";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -796,7 +796,7 @@ sub version {
 my @commands = qw(
   append	asking	auth	bgrewriteaof	bgsave	bitcount	bitop	bitpos
   blpop	brpop   brpoplpush	client	client_kill	client_getname	client_setname
-  cluster	cluster_slots
+  cluster
   config	config_get	config_set	config_resetstat	config_rewrite
   dbsize	debug_error	debug_object	debug_segfault
   decr	decrby	del	dump	echo	eval    evalsha exists	expire	expireat	flushall
@@ -843,7 +843,7 @@ I<execute>, waits for the reply from the server, and returns it. E.g.:
 
 The following wrapper methods are defined: append, asking, auth, bgrewriteaof, bgsave,
 bitcount, bitop, bitpos, blpop, brpop, brpoplpush, client, client_kill,
-client_getname, client_setname, cluster, cluster_slots, config, config_get, config_set,
+client_getname, client_setname, cluster, config, config_get, config_set,
 config_resetstat, config_rewrite, dbsize, debug_error, debug_object, debug_segfault, decr,
 decrby, del, dump, echo, eval, evalsha, exists, expire, expireat, flushall,
 flushdb, get, getbit, getrange, getset, hdel, hexists, hget, hgetall, hincrby,
@@ -953,24 +953,42 @@ sub _parse_client_list {
     return $res;
 }
 
+sub cluster_info {
+    my $self = shift;
+    my $orig = $_[-1];
+    if ( $orig && ref $orig eq 'CODE' ) {
+        my $cb = sub {
+            my ( $redis, $info ) = @_;
+            $orig->( $redis, _parse_info($info) );
+        };
+        return $self->send_command( 'CLUSTER', 'INFO', $cb );
+    }
+    else {
+        my $info = $self->execute('CLUSTER', 'INFO');
+        return _parse_info($info);
+    }
+}
+
 sub cluster_nodes {
     my $self = shift;
     my $list = $self->execute(qw(CLUSTER NODES));
     my @nodes;
     for ( split /^/, $list ) {
-        my ( $node_id, $addr, @rest ) = split / /;
-        my %flags;
-        while ( ( my $flag = shift @rest ) ne '-' ) {
-            $flags{$flag} = 1;
-        }
+        my ( $node_id, $addr, $flags, $master_id, $ping, $pong, $state, @slots ) =
+          split / /;
+        my %flags = map { $_ => 1 } split /,/, $flags;
+        my ( $host, $port ) = split /:/, $addr;
         my $node = {
             node_id            => $node_id,
             address            => $addr,
+            host               => $host,
+            port               => $port,
             flags              => \%flags,
-            last_ping_sent     => $rest[0],
-            last_pong_received => $rest[1],
-            link_state         => $rest[2],
-            slots              => $rest[3],
+            master_id          => $master_id,
+            last_ping_sent     => $ping,
+            last_pong_received => $pong,
+            link_state         => $state,
+            slots              => \@slots,
         };
         push @nodes, $node;
     }
